Analyses degree or centrality for a list of outputs from different tools
analyseDeg(networks, toolnames, n, mode = "hub")
| networks | list of list of networks per tool |
|---|---|
| toolnames | list of toolnames |
| n | number of replicates |
| mode | "hub" or "central": for hub, the degree is returned, for central, the centrality scores |
dataframe specifying tool ID and degree
Outputs a dataframe with degrees for all tools.