Calculate the top 5 hub species or central species.
analyseHubs(networks, toolnames, n, mode = "hub")
| networks | list of list of networks per tool |
|---|---|
| toolnames | list of toolnames |
| n | number of replicates |
| mode | "hub" or "central": for hub, the degree is returned, for central, the centrality scores |
Dataframe specifying tool ID and degree
The top 5 hub species or betweenness centrality species are calculated for a list with including networks from different tools.